@@ -183,6 +183,42 @@ Status validate_convolution_layer(ConvolutionLayerNode &node)
     return status;
 }
 
+/** Validates a Convolution layer node
+ *
+ * @tparam GEMMConvolutionLayer      GEMM Convolution layer function type
+ *
+ * @param[in] node Node to validate
+ *
+ * @return Status
+ */
+template <typename GEMMConvolutionLayer>
+Status validate_fused_convolution_with_post_op(FusedConvolutionWithPostOpNode &node)
+{
+    ARM_COMPUTE_LOG_GRAPH_VERBOSE("Validating fused ConvolutionLayer node with ID : " << node.id() << " and Name: " << node.name() << std::endl);
+    ARM_COMPUTE_RETURN_ERROR_ON(node.num_inputs() != 4);
+    ARM_COMPUTE_RETURN_ERROR_ON(node.num_outputs() != 1);
+
+    // Extract IO and info
+    arm_compute::ITensorInfo *input   = get_backing_tensor_info(node.input(0));
+    arm_compute::ITensorInfo *weights = get_backing_tensor_info(node.input(1));
+    arm_compute::ITensorInfo *biases  = get_backing_tensor_info(node.input(2));
+    arm_compute::ITensorInfo *output  = get_backing_tensor_info(node.output(0));
+
+    if(is_data_type_quantized_asymmetric(input->data_type()))
+    {
+        biases->set_data_type(DataType::S32);
+    }
+
+    const PadStrideInfo conv_info = node.convolution_info();
+    //const ConvolutionMethod conv_algorithm = node.convolution_method();
+    //const bool              fast_math      = node.fast_math_hint() == FastMathHint::Enabled;
+    const unsigned int num_groups = node.num_groups();
+
+    // Validate function
+    return GEMMConvolutionLayer::validate(input, weights, biases, output, conv_info,
+                                          WeightsInfo(), Size2D(1, 1), ActivationLayerInfo(), num_groups);
+}
+
 /** Validates a Depthwise Convolution layer node
  *
  * @tparam DepthwiseConvolutionLayer    Default Depthwise Convolution layer type
